@@ -26,11 +26,13 @@ from subprocess import PIPE
 from typing import Optional
 
 import pexpect
-import pkg_resources
 import pytest
+from ansible_compat.ports import cache
+from ansible_compat.runtime import Runtime
+from packaging.version import Version
 
+import molecule
 from molecule import logger, util
-from molecule.config import ansible_version
 from molecule.test.conftest import change_dir_to, molecule_directory
 from molecule.text import strip_ansi_color
 from molecule.util import run_command
@@ -46,8 +48,8 @@ MIN_PODMAN_VERSION = "1.5.1"
 @pytest.fixture(scope="session", autouse=True)
 def require_installed_package():
     try:
-        pkg_resources.require("molecule")
-    except pkg_resources.DistributionNotFound as e:
+        molecule.version("molecule")
+    except Exception as e:
         pytest.fail(
             "Functional tests require molecule package to be installed: {}".format(e)
         )
@@ -235,7 +237,7 @@ def get_virtualbox_executable():
     return shutil.which("VBoxManage")
 
 
-@util.lru_cache()
+@cache
 def supports_docker() -> bool:
     docker = get_docker_executable()
     if docker:
@@ -257,4 +259,5 @@ def supports_docker() -> bool:
 
 def min_ansible(version: str) -> bool:
     """Ensure current Ansible is newer than a given a minimal one."""
-    return ansible_version() >= ansible_version(version)
+    runtime = Runtime()
+    return bool(runtime.version >= Version(version))
