@@ -18,8 +18,19 @@
 #  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 #  DEALINGS IN THE SOFTWARE.
 
-import pytest
+from typing import Optional
 
+import pytest
+from pytest import FixtureRequest
+
+from molecule.test.functional.conftest import (
+    idempotence,
+    init_role,
+    init_scenario,
+    list_with_format_plain,
+    run_test,
+    verify,
+)
 from molecule.util import run_command
 
 
@@ -37,8 +48,12 @@ def scenario_name(request):
 
 
 @pytest.fixture
-def driver_name(request):
-    return request.param
+def driver_name(request: FixtureRequest) -> Optional[str]:
+    try:
+        # https://stackoverflow.com/q/65334215/99834
+        return request.param  # type: ignore
+    except AttributeError:
+        return None
 
 
 @pytest.mark.extensive
@@ -96,8 +111,24 @@ def test_command_create(scenario_to_test, with_scenario, scenario_name):
 @pytest.mark.parametrize(
     "scenario_to_test, driver_name, scenario_name",
     [
-        pytest.param("dependency", "delegated", "shell", id="shell"),
-        pytest.param("dependency", "delegated", "ansible-galaxy", id="galaxy"),
+        pytest.param(
+            "dependency",
+            "delegated",
+            "shell",
+            id="shell",
+            marks=pytest.mark.xfail(
+                reason="https://github.com/ansible-community/molecule/issues/3171"
+            ),
+        ),
+        pytest.param(
+            "dependency",
+            "delegated",
+            "ansible-galaxy",
+            id="galaxy",
+            marks=pytest.mark.xfail(
+                reason="https://github.com/ansible-community/molecule/issues/3171"
+            ),
+        ),
     ],
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
@@ -130,17 +161,19 @@ def test_command_destroy(scenario_to_test, with_scenario, scenario_name):
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
 def test_command_idempotence(scenario_to_test, with_scenario, scenario_name):
-    pytest.helpers.idempotence(scenario_name)
+    idempotence(scenario_name)
 
 
 @pytest.mark.parametrize("driver_name", [("delegated")], indirect=["driver_name"])
+@pytest.mark.xfail(reason="https://github.com/ansible-community/molecule/issues/3171")
 def test_command_init_role(temp_dir, driver_name, skip_test):
-    pytest.helpers.init_role(temp_dir, driver_name)
+    init_role(temp_dir, driver_name)
 
 
 @pytest.mark.parametrize("driver_name", [("delegated")], indirect=["driver_name"])
+@pytest.mark.xfail(reason="https://github.com/ansible-community/molecule/issues/3171")
 def test_command_init_scenario(temp_dir, driver_name, skip_test):
-    pytest.helpers.init_scenario(temp_dir, driver_name)
+    init_scenario(temp_dir, driver_name)
 
 
 @pytest.mark.extensive
@@ -168,7 +201,7 @@ def test_command_lint(scenario_to_test, with_scenario, scenario_name):
     indirect=["scenario_to_test", "driver_name"],
 )
 def test_command_list_with_format_plain(scenario_to_test, with_scenario, expected):
-    pytest.helpers.list_with_format_plain(expected)
+    list_with_format_plain(expected)
 
 
 # @pytest.mark.parametrize(
@@ -184,7 +217,7 @@ def test_command_list_with_format_plain(scenario_to_test, with_scenario, expecte
 #     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 # )
 # def test_command_login(scenario_to_test, with_scenario, login_args, scenario_name):
-#     pytest.helpers.login(login_args, scenario_name)
+#     login(login_args, scenario_name)
 
 
 @pytest.mark.extensive
@@ -237,7 +270,7 @@ def test_command_syntax(scenario_to_test, with_scenario, scenario_name):
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
 def test_command_test(scenario_to_test, with_scenario, scenario_name, driver_name):
-    pytest.helpers.test(driver_name, scenario_name)
+    run_test(driver_name, scenario_name)
 
 
 @pytest.mark.extensive
@@ -249,4 +282,4 @@ def test_command_test(scenario_to_test, with_scenario, scenario_name, driver_nam
     indirect=["scenario_to_test", "driver_name", "scenario_name"],
 )
 def test_command_verify(scenario_to_test, with_scenario, scenario_name):
-    pytest.helpers.verify(scenario_name)
+    verify(scenario_name)
